%
% A LaTeX class for LMS features.
%
% Created by Sunrise Setting May 2017
%
%%
%% \CharacterTable
%%  {Upper-case    \A\B\C\D\E\F\G\H\I\J\K\L\M\N\O\P\Q\R\S\T\U\V\W\X\Y\Z
%%   Lower-case    \a\b\c\d\e\f\g\h\i\j\k\l\m\n\o\p\q\r\s\t\u\v\w\x\y\z
%%   Digits        \0\1\2\3\4\5\6\7\8\9
%%   Exclamation   \!     Double quote  \"     Hash (number) \#
%%   Dollar        \$     Percent       \%     Ampersand     \&
%%   Acute accent  \'     Left paren    \(     Right paren   \)
%%   Asterisk      \*     Plus          \+     Comma         \,
%%   Minus         \-     Point         \.     Solidus       \/
%%   Colon         \:     Semicolon     \;     Less than     \<
%%   Equals        \=     Greater than  \>     Question mark \?
%%   Commercial at \@     Left bracket  \[     Backslash     \\
%%   Right bracket \]     Circumflex    \^     Underscore    \_
%%   Grave accent  \`     Left brace    \{     Vertical bar  \|
%%   Right brace   \}     Tilde         \~}
%%
\NeedsTeXFormat{LaTeX2e}
\ProvidesClass{lmsedition}[19/06/2019, v2.5]
\RequirePackage[utf8]{inputenc}
\RequirePackage[english]{babel}
\RequirePackage{ifthen}
\RequirePackage{calc}

\newcommand{\@cmrfont}{0}
\DeclareOption{cmrfont}{\renewcommand{\@cmrfont}{1}}

\AtEndOfClass{\RequirePackage{microtype}}
\DeclareOption*{\PassOptionsToClass{\CurrentOption}{book}}
\ProcessOptions*
\LoadClass[10pt]{book}
\RequirePackage{graphicx,xcolor}
\RequirePackage{wrapfig}
\RequirePackage[font={small},justification=raggedright,singlelinecheck=false]{caption}
\RequirePackage[square,numbers]{natbib}
\RequirePackage{amsmath,amsfonts,amssymb,amsthm}
\RequirePackage{lipsum,multicol,adjustbox,tabularx,tcolorbox}
\RequirePackage{hyperref}
\RequirePackage[pagestyles,outermarks]{titlesec}
\RequirePackage{lmodern} % monospace font
% \RequirePackage[scale=0.89]{tgheros} % Helvetica is too big
\RequirePackage[cal=boondoxo]{mathalfa} % mathcal from STIX, unslanted a bit
\RequirePackage{tikz}
\usepackage{setspace}
\usepackage{eurosym}
\usepackage[final]{pdfpages}
\usepackage{tabu}

%\usepackage{float}
\usepackage[hang,flushmargin]{footmisc}
\usepackage{balance}

\ifodd\@cmrfont
\RequirePackage[OT1]{fontenc}
\renewcommand*\familydefault{\sfdefault}
\renewcommand{\rmdefault}{cmr}
\else%
\RequirePackage[T1]{fontenc}
\RequirePackage{Baskervaldx} % tosf in text, tlf in math
\RequirePackage[baskervaldx,bigdelims,vvarbb]{newtxmath} % math italic letters from Baskervaldx
\renewcommand{\rmdefault}{Baskervaldx-OsF}
\renewcommand{\sfdefault}{gillius} 
\RequirePackage[default]{gillius}
\fi%

\hypersetup{colorlinks,linkcolor={red!50!black},citecolor={blue!50!black},urlcolor={blue!80!black},hidelinks}

\RequirePackage[paperwidth=210mm, paperheight=270mm,
                textwidth=158mm, textheight=227mm,
			    headheight=14mm, headsep=8mm,
			    footskip=14mm, columnsep=8mm,
				includeheadfoot, heightrounded,
			    %hmarginratio=1:1, vmarginratio=1:1,
			    %layoutvoffset= 10mm, layouthoffset= 10mm,
			    marginparwidth=32mm,
			    % showframe=true, showcrop=true,
			    onecolumn,twoside]{geometry}

\usepackage[width=230mm, height=290mm, cam, axes, pdftex, center]{crop}
  
\usepackage{lmspenality}



%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Editorial:  CMYK 95 78, 43, 38 
% News: CMYK 95 78, 43, 38 thebibliography
% LMS business: CMYK 90, 59, 72, 38 
% Features: CMYK 35, 100, 37, 10 
% Early Career Researcher: CMYK 75, 34, 46, 8 
% Reviews: CMYK 63, 33, 24, 1 
% Obituaries: CMYK 90, 59, 47, 20 
% Events: CMYK 82, 34, 12, 0 


\definecolor{acolor}{cmyk}{0.63, 0.33, 0.24, 0.10}  % Reviews
\definecolor{bcolor}{cmyk}{0.90, 0.59, 0.47, 0.20}  % Obituaries
\definecolor{ccolor}{cmyk}{0.82, 0.34, 0.12, 0.00}  % Events
\definecolor{dcolor}{cmyk}{0.35, 1.00, 0.37, 0.10}  % Features
\definecolor{ecolor}{cmyk}{0.95, 0.78, 0.43, 0.38}  % News
\definecolor{fcolor}{cmyk}{0.95, 0.78, 0.43, 0.38}	% Editorial
\definecolor{gcolor}{cmyk}{0.90, 0.59, 0.72, 0.38}  % LMS business
\definecolor{hcolor}{cmyk}{0.75, 0.34, 0.46, 0.08}  % Early Career Researcher %IM edit


\setlength\fboxsep{5pt}
\def\rhpgL{\parbox{\dimexpr\marginparwidth\relax}{\centering\color{white}\thepage\vphantom{|/}}}
\def\rhpgR{\parbox{\dimexpr\marginparwidth\relax}{\centering\color{white}\thepage\vphantom{|/}}}
\def\rhttL{\parbox{\dimexpr\linewidth-2\fboxsep}{\color{white}\sectiontitle\vphantom{|/}}}
\def\rhttR{\hspace*{-\textwidth}\color{white}\sectiontitle\vphantom{|/}}
\def\rhttFL{\hspace*{\textwidth}\vphantom{|/}}
 
\def\issue#1{\gdef\theissue{#1 }}%
  \def\theissue{0000}%
\def\monthyear#1{\gdef\themonthyear{#1 }}%
  \def\themonthyear{0000}%
  
\RequirePackage{enumerate}
\addtolength{\itemindent}{-2em}
\renewcommand{\labelenumi}{(\arabic{enumi})}
\renewcommand{\labelenumii}{(\alph{enumii})}
\renewcommand{\labelenumiii}{(\roman{enumiii})}

{\theoremstyle{theorem}
 \newtheorem{assumption}{Assumption} 
 \newtheorem{corollary}{Corollary}
 \newtheorem{lemma}{Lemma} 
 \newtheorem{proposition}{Proposition} 
 \newtheorem{theorem}{Theorem} 
 }  
{\theoremstyle{definition}
 \newtheorem{claim}{Claim} 
 \newtheorem{hypothesis}{Hypothesis} 
 \newtheorem{notation}{Notation} 
 \newtheorem{observation}{Observation} 
 \newtheorem{algorithm}{Algorithm} 
 \newtheorem{assertion}{Assertion} 
 \newtheorem{definition}{Definition} 
 \newtheorem{fact}{Fact} 
 \newtheorem{conjecture}{Conjecture} 
 \newtheorem{problem}{Problem} 
 \newtheorem{remark}{Remark}  
 \newtheorem{note}{Note} 
 \newtheorem{question}{Question} 
 \newtheorem{listenv}{List} 
 \newtheorem{property}{Property} 
 \newtheorem{example}{Example} 
}  
  
%size \normalsize:10pt
% \renewcommand\scriptsize{\@setfontsize\scriptsize\@viipt\@viiipt} %7
% \renewcommand\tiny{\@setfontsize\tiny\@vpt\@vipt} %5
% \renewcommand\large{\@setfontsize\large\@xiipt\@xivpt} %12
% \renewcommand\Large{\@setfontsize\Large\@xivpt{16\p@}} %14.4
% \renewcommand\LARGE{\@setfontsize\LARGE\@xviipt{21\p@}} %17.28
% \renewcommand\huge{\@setfontsize\huge\@xxpt\@xxvpt} %20.74
% \renewcommand\Huge{\@setfontsize\Huge\@xxvpt{30\p@}} %24.88

\def\xpt{\fontsize{10}{12}\selectfont}
\def\xiipt{\fontsize{12}{14}\selectfont}
\def\xivpt{\fontsize{14}{18}\selectfont}
\def\xvpt{\fontsize{15}{19}\selectfont}
\def\xviipt{\fontsize{17}{22}\selectfont}
\def\xxpt{\fontsize{20}{25}\selectfont}
\def\xxiipt{\fontsize{22}{27}\selectfont}

%fonts
\newcommand\lmsfont@section              {\normalfont\normalsize\bfseries\boldmath}
\newcommand\lmsfont@frontmattersection   {\lmsfont@section\rmfamily}
\newcommand\lmsfont@subsection           {\normalfont\small\bfseries\itshape\boldmath}
\newcommand\lmsfont@frontmattersubsection{\lmsfont@subsection\upshape}
\newcommand\lmsfont@subsubsection		  {\normalfont\small\itshape}
\newcommand\lmsfont@paragraph    		  {\normalfont\normalsize\bfseries\boldmath}
\newcommand\lmsfont@subparagraph 		  {\normalfont\normalsize\itshape}

%sectioning
\renewcommand\section{\@startsection {section}{1}{\z@}%
                                   {-24pt \@plus -6pt \@minus -3pt}%
                                   {12pt}%
                                   {\lmsfont@section}}
\renewcommand\subsection{\@startsection{subsection}{2}{\z@}%
                                   {-18pt \@plus -6pt \@minus -3pt}%
                                   {6pt}%
                                    {\lmsfont@subsection}}
\renewcommand\subsubsection{\@startsection{subsubsection}{3}{\z@}%
                                   {-22pt \@plus -2pt \@minus -2pt}%
                                   {6pt}%
                                    {\lmsfont@subsubsection}}
\renewcommand\paragraph{\@startsection{paragraph}{4}{\z@}%
                                   {-12pt \@plus -2pt \@minus -2pt}%
                                    {.001pt}%
                                    {\lmsfont@paragraph}}
\renewcommand\subparagraph{\@startsection{subparagraph}{5}{\z@}%UF changed \parindent to \z@
                                    {3.25ex \@plus1ex \@minus .2ex}%
                                     {-1em}%
                                     {\lmsfont@subparagraph}}
									 
\makeatletter\gdef\ttl@savemark{}\makeatother									 
\let\oldthebibliography\thebibliography
\let\endoldthebibliography\endthebibliography
\renewcommand{\bibsection}{}
\renewenvironment{thebibliography}[1]{
\begin{color}{dcolor}
  \begin{oldthebibliography}{#1}
 \renewcommand{\refname}{FURTHER READING} 
  \section*{\refname}
	\setlength{\labelwidth}{0em}
   \setlength{\itemsep}{0em}
    \setlength{\parskip}{0em}
	\setlength{\leftmargin}{0em}
	\setlength{\itemindent}{2mm}
}{\end{oldthebibliography}\end{color}}


\newenvironment{ecrbibliography}[1]{ %IM edit
\begin{color}{hcolor}
  \begin{oldthebibliography}{#1}
 \renewcommand{\refname}{FURTHER READING} 
  \section*{\refname}
	\setlength{\labelwidth}{0em}
    \setlength{\itemsep}{0em}
    \setlength{\parskip}{0em}
	\setlength{\leftmargin}{0em}
	\setlength{\itemindent}{2mm}
}{\end{oldthebibliography}\end{color}}

\newenvironment{revbibliography}[1]{ %IM edit
\begin{color}{acolor}
  \begin{oldthebibliography}{#1}
 \renewcommand{\refname}{FURTHER READING} 
  \section*{\refname}
	\setlength{\labelwidth}{0em}
    \setlength{\itemsep}{0em}
    \setlength{\parskip}{0em}
	\setlength{\leftmargin}{0em}
	\setlength{\itemindent}{2mm}
}{\end{oldthebibliography}\end{color}}

\newenvironment{obitbibliography}[1]{ %IM edit
\begin{color}{bcolor}
  \begin{oldthebibliography}{#1}
 \renewcommand{\refname}{\uppercase{References}} 
  \section*{\refname}
	\setlength{\labelwidth}{0em}
    \setlength{\itemsep}{0em}
    \setlength{\parskip}{0em}
	\setlength{\leftmargin}{0em}
	\setlength{\itemindent}{2mm}
}{\end{oldthebibliography}\end{color}}


\newenvironment{widepage}{%
  \begin{list}{}{%
      \setlength{\topsep}{0pt}%
      %\addtolength{\leftmargin}{-\marginparwidth}%
	  \addtolength{\leftmargin}{-2pc}%
      \addtolength{\rightmargin}{-\marginparwidth}%
      \setlength{\listparindent}{\parindent}%
      \setlength{\itemindent}{\parindent}%
      \setlength{\parsep}{\parskip}}%
  \item[]}
  {\end{list}}

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

\usepackage{newfloat}
\DeclareFloatingEnvironment[fileext=frm,placement={!ht},name={}]{lmsfloat}
\usepackage[framemethod=TikZ]{mdframed}
\captionsetup[lmsfloat]{labelfont=bf}

\newenvironment{bandbox}[1][]
  {\ifthenelse{\equal{#1}{dcolor}}{\begin{tcolorbox}[arc=0pt,colback=dcolor!5,colframe=dcolor,title=\quad,boxrule=0mm]}{}
  \ifthenelse{\equal{#1}{acolor}}{\begin{tcolorbox}[arc=0pt,colback=acolor!5,colframe=acolor,title=\quad,boxrule=0mm]}{}
  \ifthenelse{\equal{#1}{ccolor}}{\begin{tcolorbox}[arc=0pt,colback=ccolor!5,colframe=ccolor,title=\quad,boxrule=0mm]}{}
  \ifthenelse{\equal{#1}{fcolor}}{\begin{tcolorbox}[arc=0pt,colback=fcolor!5,colframe=fcolor,title=\quad,boxrule=0mm]}{}
    \ifthenelse{\equal{#1}{gcolor}}{\begin{tcolorbox}[arc=0pt,colback=gcolor!5,colframe=gcolor,title=\quad,boxrule=0mm]}{} %IM edit
        \ifthenelse{\equal{#1}{hcolor}}{\begin{tcolorbox}[arc=0pt,colback=hcolor!5,colframe=hcolor,title=\quad,boxrule=0mm]}{} %IM edit
  }{\end{tcolorbox}}

 
\newenvironment{twoblock}
  {\begin{multicols}{2} 
   }{\end{multicols}}
  
\newenvironment{eventplan}
  {\begin{tabular}{@{}l@{\qquad}l}
  }{\end{tabular}}  

\newenvironment{Figure}
  {\par\medskip\noindent\minipage{\textwidth}}
  {\endminipage\par\medskip}
  
\newenvironment{cimage}
  {\medskip\noindent\begin{minipage}{\columnwidth}
  \centering \captionsetup{labelformat=empty}
  }
  {\end{minipage}\medskip}

\newenvironment{fimage}
  {\medskip\noindent\begin{minipage}{\textwidth}
  \centering \captionsetup{labelformat=empty}
  }
  {\end{minipage}\medskip}  
  
\newenvironment{tcenter}
 {\parskip=0pt\par\nopagebreak\centering}
 {\par\noindent\ignorespacesafterend}

 
\newcommand\clpage{\clearpage\phantomsection\onecolumn} 

\newcounter{reftaskno}
\DeclareRobustCommand{\pgtask}[1]{%
   \refstepcounter{reftaskno}%%\thereftaskno
   \label{#1}}  
 
%%%%%%%%%%%% event page -ccolor %%%%%%%%%%%  

\newpagestyle{event}{
\sethead[\bfseries\llap{\colorbox{ccolor}{\rhpgL}}\hskip-0.5pt\colorbox{ccolor}{\rhttL}][][]%% even-head
{\colorbox{ccolor}{\rhttFL}}{}{\bfseries\colorbox{ccolor}{\rhttR}\hskip-0.5pt\rlap{\colorbox{ccolor}{\rhpgR}}}%% odd-head 
\setfoot{}{}{}}

\newenvironment{eventpage}
  {\clpage\pagestyle{event}
  }{\clearpage\pagestyle{event}}  
  
\newcommand\eventpageentry{\pageref{evnpage_start}}
%\newcommand\eventpagerange{\pageref{evnpage_start}--\pageref{evnpage_end}}
%\newcommand\eventpagerange{\pageref{evnpage_start}}
\newcommand\eventpagerange{}

 
\newenvironment{abspara}
  {\smallskip\begin{color}{ecolor}\xiipt\rmfamily\selectfont}
  {\end{color}\smallskip}
\newenvironment{dispara}
  {\smallskip\begin{color}{ccolor}\xvpt\rmfamily\itshape\selectfont}
  {\vskip5pt\end{color}\smallskip}
\newenvironment{quote1}
  {\bigskip\begin{color}{ccolor}\normalsize\selectfont}
  {\end{color}\bigskip}
\newcommand\eventtitle[1]{\textcolor{ccolor}{\xxpt\rmfamily\selectfont #1}\smallskip}
\newcommand\eventsection[1]{\bigskip\textcolor{ccolor}{\selectfont #1}\bigskip}  
\newcommand\eventdate[1]{\textcolor{ccolor}{#1}\bigskip}
\newcommand\eventname[1]{\bigskip\textcolor{ccolor}{\xiipt\rmfamily\selectfont #1}}

\newcommand\leventname[1]{\raisebox{-3pt}{\includegraphics[width=15px]{img/lgevent.png}}
						\textcolor{ccolor}{\enskip\xiipt\rmfamily\selectfont #1}}

%\newcommand\leventname[1]{\raisebox{-3pt}{\hspace*{-\marginparsep}\enskip\llap{
%	\includegraphics[width=15px]{img/lgevent.png}}}\textcolor{ccolor}{\enskip\xiipt\rmfamily\selectfont #1}}
\newcommand\eventdividerbar{\colorbox{ccolor}{\parbox{\dimexpr\linewidth-2\fboxsep}{\quad}}\bigskip}
\newcommand\eventdivider{\raisebox{-8pt}{\hspace*{-\marginparsep}\llap{
    \colorbox{ccolor}{\hspace*{30mm}\vphantom{|/}}}}\hskip-0.5pt\textcolor{ccolor}{\rule[1mm]{161mm}{0.5mm}}\vskip-27pt}

%%%%%%%%%%%% editorial page - ecolor %%%%%%%%%%%

\newpagestyle{editorial}{
\sethead[\bfseries\llap{\colorbox{fcolor}{\rhpgL}}\hskip-0.5pt\colorbox{fcolor}{\rhttL}][][]%
{\colorbox{ecolor}{\rhttFL}}{}{\bfseries\colorbox{fcolor}{\rhttR}\rlap{\colorbox{fcolor}{\rhpgR}}}\setfoot{}{}{}}
	
\newenvironment{edpage}
  {\clpage\pagestyle{editorial} % IM edit
 % \begin{color}{hcolor} 
 % }{\end{color}\clearpage\pagestyle{editorial}}
}{\clearpage\pagestyle{editorial}} 

\newcommand\edpageentry{\pageref{edpage_start}}
%\newcommand\edpagerange{\pageref{edpage_start}--\pageref{edpage_end}}
%\newcommand\edpagerange{\pageref{edpage_start}}
\newcommand\edpagerange{}

	
%%%%%%%%%%%% news page - ecolor %%%%%%%%%%%

\newpagestyle{news}{
\sethead[\bfseries\llap{\colorbox{ecolor}{\rhpgL}}\hskip-0.5pt\colorbox{ecolor}{\rhttL}][][]%
{\colorbox{ecolor}{\rhttFL}}{}{\bfseries\colorbox{ecolor}{\rhttR}\rlap{\colorbox{ecolor}{\rhpgR}}}\setfoot{}{}{}}
	
\newcommand\newstitle[1]{\textcolor{ecolor}{\begin{tcenter}\xxpt\rmfamily\selectfont #1\end{tcenter}}\smallskip}
\newcommand\newssection[1]{\bigskip\textcolor{ecolor}{\selectfont #1}\bigskip}  
\newcommand\newsname[1]{\smallskip\textcolor{ecolor}{\rmfamily\selectfont\xivpt #1}\smallskip}
\newcommand\newsdivider{\raisebox{-8pt}{\hspace*{-\marginparsep}\llap{
    \colorbox{ecolor}{\hspace*{30mm}\vphantom{|/}}}}\hskip-0.5pt\textcolor{ecolor}{\rule[1mm]{161mm}{0.5mm}}\vskip-27pt}
	
\newcommand\revfigcaption[1]{\captionof{figure}{\textcolor{acolor}{#1}}} %IM edit
\newcommand\obitfigcaption[1]{\captionof{figure}{\textcolor{bcolor}{#1}}} 
\newcommand\eventfigcaption[1]{\captionof{figure}{\textcolor{ccolor}{#1}}}
\newcommand\featfigcaption[1]{\captionof{figure}{\textcolor{dcolor}{#1}}}
\newcommand\newsfigcaption[1]{\captionof{figure}{\textcolor{ecolor}{#1}}}
\newcommand\editfigcaption[1]{\captionof{figure}{\textcolor{fcolor}{#1}}}
\newcommand\repfigcaption[1]{\captionof{figure}{\textcolor{gcolor}{#1}}}
\newcommand\ecrfigcaption[1]{\captionof{figure}{\textcolor{hcolor}{#1}}}

\newcommand\figcaption[1]{\captionof{figure}{\textcolor{ecolor}{#1}}}


\def\thepart{\alph{part}}

\newenvironment{newspage}
  {\clpage\pagestyle{news} %IM edit
 % \begin{color}{hcolor}  
 % }{\end{color}\clearpage\pagestyle{news}}   
  }{\clearpage\pagestyle{news}}

\newcommand\newspageentry{\pageref{news_start}}
%\newcommand\newspagerange{\pageref{news_start}--\pageref{news_end}}
%\newcommand\newspagerange{\pageref{news_start}}
\newcommand\newspagerange{}

  
\newenvironment{newsblock}
  {\clpage\pagestyle{news}\begin{color}{hcolor} 
  }{\end{color}
  \clearpage\pagestyle{news}}
 
  
%%%%%%%%%%%%  feature / article page - dcolor %%%%%%%%%%%

\newpagestyle{feature}{
\sethead[\bfseries\llap{\colorbox{dcolor}{\rhpgL}}\hskip-0.5pt\colorbox{dcolor}{\rhttL}][][]%
{\colorbox{dcolor}{\rhttFL}}{}{\bfseries\colorbox{dcolor}{\rhttR}\rlap{\colorbox{dcolor}{\rhpgR}}}\setfoot{}{}{}}

\newenvironment{articlepage}
  {\clpage\pagestyle{feature}
  }{\clearpage\pagestyle{feature}}
  
\newcommand\featureentry{\pageref{fea_start}}
%\newcommand\featurerange{\pageref{fea_start}--\pageref{fea_end}} %toc page display
%\newcommand\featurerange{\pageref{fea_start}}
\newcommand\featurerange{}
  
\newenvironment{articleabs}
  {\begin{color}{dcolor}\selectfont Abstract.}
  {\end{color}\bigskip}
  
   \newenvironment{articlenoabs} %IM edit
  {\begin{color}{dcolor}\selectfont }
  {\end{color}\bigskip} 
  
\newcommand\articletitle[1]{\begin{tcenter}\textcolor{dcolor}{\xxpt\rmfamily\selectfont #1}\end{tcenter}\medskip}
\newcommand\articleauthor[1]{\begin{tcenter}\textcolor{dcolor}{\uppercase{#1}}\end{tcenter}\medskip}
  
 \let\biggl\left
  \let\biggr\right
   \let\endproof\relax
	\def\Halmos{\hfill$\square$}  


\newcommand\featname[1]{\smallskip\begingroup\begin{flushleft}\rmfamily\selectfont\xivpt\textcolor{dcolor}{#1}\end{flushleft}\endgroup} %IM edit


%%%%%%%%%%%% review page - acolor %%%%%%%%%%%

\newpagestyle{review}{
\sethead[\bfseries\llap{\colorbox{acolor}{\rhpgL}}\hskip-0.5pt\colorbox{acolor}{\rhttL}][][]%
{\colorbox{acolor}{\rhttFL}}{}{\bfseries\colorbox{acolor}{\rhttR}\rlap{\colorbox{acolor}{\rhpgR}}}\setfoot{}{}{}}

\newenvironment{revpage}
  {\clpage\pagestyle{review}
  }{\clearpage\pagestyle{review}}

\newcommand\revpageentry{\pageref{revpage_start}}
%\newcommand\revpagerange{\pageref{revpage_start}--\pageref{revpage_end}}
%\newcommand\revpagerange{\pageref{revpage_start}}
\newcommand\revpagerange{}
    
\newcommand\revtitle[1]{\begin{tcenter}
  \xxpt\rmfamily\selectfont \textcolor{acolor}{#1}\end{tcenter}\smallskip}

\newcommand\revsection[1]{\bigskip\textcolor{acolor}{\selectfont #1}\bigskip}  
  
\newenvironment{revabs}
  {\smallskip\begin{tcenter}\begin{spacing}{1.6}\begin{color}{acolor}\xivpt\selectfont}
  {\end{color}\end{spacing}\end{tcenter}\bigskip}

\newcommand\revauthor[1]{\begin{tcenter}\textcolor{acolor}{#1}\end{tcenter}\medskip}


% \newcommand\revabs[1]{\begin{tcenter}
  % \xivpt\selectfont \textcolor{acolor}{#1}\end{tcenter}}
  

%%%%%%%%%%%% EARLY CAREER page - hcolor %%%%%%%%%%%

\newpagestyle{ecrpage}{
\sethead[\bfseries\llap{\colorbox{hcolor}{\rhpgL}}\hskip-0.5pt\colorbox{hcolor}{\rhttL}][][]%
{\colorbox{hcolor}{\rhttFL}}{}{\bfseries\colorbox{hcolor}{\rhttR}\rlap{\colorbox{hcolor}{\rhpgR}}}\setfoot{}{}{}}

\newenvironment{ecrpage}
  {\clpage\pagestyle{ecrpage}
  }{\clearpage\pagestyle{ecrpage}}

\newenvironment{ecrabs}
  {\smallskip\begin{color}{hcolor}\selectfont}
  {\end{color}\bigskip} 
  
  
  \newenvironment{ecrabspara}%IM edit
  {\smallskip\begin{color}{hcolor}\xiipt\rmfamily\selectfont}
  {\end{color}\bigskip}
  

\newenvironment{ecrintro}
  {\smallskip\selectfont}
%  {\smallskip\selectfont\itshape} %IM edit 
  {\bigskip} 

\newcommand\ecrtitle[1]{\begin{tcenter}\textcolor{hcolor}{\xxpt\rmfamily\selectfont #1}\end{tcenter}\medskip}
\newcommand\ecrauthor[1]{\begin{tcenter}\textcolor{hcolor}{\uppercase{#1}}\end{tcenter}\medskip}
\newcommand\ecrname[1]{\smallskip\textcolor{hcolor}{\xivpt\rmfamily\selectfont #1}}


\newcommand\ecrpageentry{\pageref{ecrpage_start}}
%\newcommand\ecrpagerange{\pageref{ecrpage_start}--\pageref{ecrpage_end}}
%\newcommand\ecrpagerange{\pageref{ecrpage_start}}
\newcommand\ecrpagerange{}
   
%%%%%%%%%%%% orbpage page - bcolor %%%%%%%%%%%

\newpagestyle{orbituaries}{
\sethead[\bfseries\llap{\colorbox{bcolor}{\rhpgL}}\hskip-0.5pt\colorbox{bcolor}{\rhttL}][][]%
{\colorbox{bcolor}{\rhttFL}}{}{\bfseries\colorbox{bcolor}{\rhttR}\rlap{\colorbox{bcolor}{\rhpgR}}}\setfoot{}{}{}}

\newenvironment{orbpage}
  {\clpage\pagestyle{orbituaries}
  }{\clearpage\pagestyle{orbituaries}}


\newcommand\orbtitle[1]{\begin{tcenter}
  \xxpt\rmfamily\selectfont \textcolor{bcolor}{#1}\end{tcenter}\smallskip} 
  
\newcommand\orbsection[1]{\bigskip\textcolor{bcolor}{\selectfont #1}\bigskip}
  
\newcommand\orbname[1]{\smallskip\textcolor{bcolor}{\xivpt\rmfamily\selectfont #1}}
\newcommand\orbdate[1]{\textcolor{bcolor}{#1}\bigskip}
\newcommand\orbdividerbar{\textcolor{bcolor}{\rule{\textwidth}{2mm}}}

\newcommand\orbpageentry{\pageref{orbpage_start}}
%\newcommand\orbpagerange{\pageref{orbpage_start}--\pageref{orbpage_end}}
%\newcommand\orbpagerange{\pageref{orbpage_start}}
\newcommand\orbpagerange{}

%%%%%%%%%%%% recordpage page - gcolor %%%%%%%%%%%
% IM edit to colour
\newpagestyle{recpage}{
\sethead[\bfseries\llap{\colorbox{gcolor}{\rhpgL}}\hskip-0.5pt\colorbox{gcolor}{\rhttL}][][]%
{\colorbox{gcolor}{\rhttFL}}{}{\bfseries\colorbox{gcolor}{\rhttR}\rlap{\colorbox{gcolor}{\rhpgR}}}\setfoot{}{}{}}

\newenvironment{recordpage}
  {\clpage\pagestyle{recpage}
  }{\clearpage\pagestyle{recpage}}


\newcommand\recpageentry{\pageref{recstart}}   
%\newcommand\recpagerange{\pageref{rec_start}} 
%\newcommand\recpagerange{\pageref{rec_start}--\pageref{rec_end}} 
\newcommand\recpagerange{} 

\newcommand\rectitle[1]{\textcolor{gcolor}{\begin{tcenter}\xxpt\rmfamily\selectfont #1\end{tcenter}}\smallskip}
\newcommand\recsection[1]{\bigskip\textcolor{gcolor}{#1}\bigskip}
\newcommand\recname[1]{\smallskip\begingroup\begin{flushleft}\rmfamily\selectfont\xivpt\textcolor{gcolor}{#1}\end{flushleft}\endgroup}
\newcommand\recdivider{\raisebox{-8pt}{\hspace*{-\marginparsep}\llap{
    \colorbox{gcolor}{\hspace*{30mm}\vphantom{|/}}}}\hskip-0.5pt\textcolor{ecolor}{\rule[1mm]{161mm}{0.5mm}}\vskip-27pt}

% \newenvironment{revtbox}
  % {\begin{myfloat}[tb]
  % \begin{tcolorbox}[arc=0pt,colback=fcolor!5,colframe=fcolor,title=\quad,boxrule=0mm]
  % }{\end{tcolorbox}\end{myfloat}}
	

%%%%%%%%%%%% front ecolor %%%%%%%%%%%	

\newpagestyle{cdpage}{
\sethead[][][]%
{}{}{}\setfoot{}{}{}}	
	
\newcommand\mpar{\hspace*{11mm}}	
	
\newcommand\whiteboxlogo{\begingroup
\begin{tikzpicture}[remember picture,overlay]
%\fill[white]([yshift=-55mm]current page.north west) rectangle (current page.north east);
  \fill[white]([xshift=-5mm,yshift=-55mm]current page.north west) rectangle ([xshift=5mm,yshift=5mm]current page.north east);
\end{tikzpicture}
	\vskip-20mm\hfill\includegraphics[width=0.6\textwidth]{img/LMSlogo.png}\hspace*{18pt}\vskip20mm
\endgroup}	
	
\newenvironment{coverpage}
  {\begingroup\pagestyle{cdpage}\onecolumn
  \rmfamily\selectfont\pagecolor{ecolor}\begin{widepage}\begin{color}{white}  
  }{\end{color}\end{widepage}\clearpage\pagestyle{empty}\endgroup}
  
\newenvironment{copyrightpage}
  {%\null\vfill
  \pagecolor{ecolor}
  \thispagestyle{empty}
  \begin{flushbottom}
  \begin{color}{white}
  \setlength{\columnsep}{23mm}
  }{\end{color}\end{flushbottom}
  \clearpage\nopagecolor
  \pagecolor{white}
\thispagestyle{empty}}

%\newcommand\cphead[1]{\begingroup{\bigskip\xivpt\rmfamily\selectfont #1 \smallskip}\endgroup}

\newcommand\cphead[1]{\begingroup{\smallskip\selectfont #1 \smallskip}\endgroup}

%%%%%%%%%%%% back page - ecolor %%%%%%%%%%%	

\RequirePackage{flushend}

\newenvironment{calenderpage}
  {\begingroup\clpage\pagestyle{cdpage}
  \pagecolor{ecolor}\begin{color}{white}
  }{\end{color}\flushend\clearpage\pagestyle{empty}\nopagecolor\endgroup}
  
\newcommand\colpageentry{\pageref{clnpage_start}}
%\newcommand\colpagerange{\pageref{clnpage_start}--\pageref{clnpage_end}}
%\newcommand\colpagerange{\pageref{clnpage_start}}
\newcommand\colpagerange{}


\newcommand\cdtitle[1]{\begingroup\textcolor{white}{\begin{tcenter}\rmfamily\xxpt  #1\end{tcenter}}\bigskip\endgroup} 
\newcommand\cdmonth[1]{\begingroup{\smallskip\xivpt\rmfamily\selectfont #1 \smallskip}\endgroup}

  \newcolumntype{R}[1]{>{\raggedleft\let\newline\\\arraybackslash\hspace{0pt}}m{#1}} %IM edit

\newenvironment{cdplan}
 % {\begingroup\begin{tabular}{@{}r@{\enskip}@{|}@{\enskip}p{6cm}}%IM edit
{\begingroup\begin{tabular}{R{14mm}@{\hspace{3mm}}p{58mm}}
  }{\end{tabular}\endgroup}  
  
  
		  
%%^^^^^^^^^^^^^^^^^^^^^^^^ Table of Content ^^^^^^^^^^^^^^^^

\usepackage{titletoc}
\usepackage{framed}
\contentsmargin{20mm}
\usepackage{tocloft}
\tocloftpagestyle{plain}


\newcommand\tocpart[3]{\cftaddtitleline{toc}{part}{\textcolor{#1}{#2}}{\textcolor{#1}{#3}}}
\newcommand\tocsection[3]{\pgtask{#2}\sectionmark{#2}\cftaddtitleline{toc}{section}{\textcolor{#1}{#3}}{\textcolor{#1}{\xpt\thepage}}}
\newcommand\tocsubsection[2]{\cftaddtitleline{toc}{subsection}{\textcolor{#1}{#2}}{\textcolor{#1}{\xpt\thepage}}}
\newcommand\tocsecdummy{\cftaddtitleline{toc}{section}{}}

\renewcommand{\cfttoctitlefont}{\color{fcolor}\xxpt\rmfamily\MakeUppercase}
%\renewcommand{\cftaftertoctitle}{\hfill}

%IM edit commented below
%\titlecontents{part}[\fill]
% {\vspace*{1\baselineskip}
% \fontsize{16}{19}\rmfamily}
% {}{}
% {\hspace*{15pc}\newline\contentspage\hspace*{20pc}}
% [\vspace*{-2.3\baselineskip}]

%\titlecontents{section}[84mm]
%  {\vspace*{0.7\baselineskip}\xiipt}
%  {\raggedright}{}
%  {\hfill\contentspage}

%\titlecontents{subsection}[84mm]
%  {\fontsize{10}{12}\selectfont}
%  {\raggedright}{}
%  {\hfill\contentspage}

\titlecontents{part}[\fill] %IM edit
 {\vspace*{1\baselineskip}
 \fontsize{16}{19}\rmfamily}
 {}{}
 {\hspace*{20pc}\newline\contentspage\hspace*{25pc}}
 [\vspace*{-2.3\baselineskip}]

\titlecontents{section}[64mm]
  {\vspace*{0.7\baselineskip}\xiipt}
  {\raggedright}{}
  {\hfill\contentspage}

\titlecontents{subsection}[64mm]
  {\fontsize{10}{12}\selectfont}
  {\raggedright}{}
  {\hfill\contentspage}

 \hypersetup{hidelinks}
 
\contentsfinish 

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
  
\makeatletter
\def\fakeH@#1#2{%
  \vtop{\m@th\ialign{##\cr
    \hfil$#1\kern-.8pt\operator@font \textsf{o}$\hfil\cr
    \noalign{\nointerlineskip\kern-7\ex@}#2\cr
    \noalign{\nointerlineskip\kern-\ex@}\cr}}%
}
\def\fakHo{%
  \mathop{\mathpalette\fakeH@{\'{}\kern-.6pt\'{}}}\nmlimits@
\!}
\makeatother

\usepackage{atbegshi}
\newcommand{\fullpageadd}[1]{\begingroup
%\includepdf[pages=-,templatesize={220mm}{280mm},noautoscale=true,offset=5mm 5mm]{#1}\end{center}\endgroup}
\includepdf[pages=-,clip,trim=5mm 5mm 5mm 5mm]{#1}\endgroup}


\endinput

% end of file lmsarticle.cls

